"""
Helper functions/values for huobi rest client
"""


REQUIRED_HEADERS = {
    'user-agent': 'Mozilla/5.0 (Windows NT 6.1; WOW64) '
                  'AppleWebKit/537.36 (KHTML, like Gecko) '
                  'Chrome/39.0.2171.71 Safari/537.36',
    'content-type': 'application/x-www-form-urlencoded',
}

REQUIRED_POST_HEADERS = {
    'content-type': 'application/json',
    'accept': 'application/json'
}
